@@ -6,13 +6,25 @@ import subprocess
 import yaml
 import json
 import re
-from enum import Enum
 import anyconfig
 from dotenv import load_dotenv
 import docker
-from pprint import pprint
-import re
 from shutil import which
+import sys
+import platform
+from typing import Optional
+
+# Linux
+# ('Linux', '5.4.0-52-generic', '#57-Ubuntu SMP Thu Oct 15 10:57:00 UTC 2020')
+# 5.4.0-52-generic
+
+# Darwin
+# ('Darwin', '19.6.0', 'Darwin Kernel Version 19.6.0: Thu Jun 18 20:49:00 PDT 2020; root:xnu-6153.141.1~1/RELEASE_X86_64')
+# 19.6.0
+print(platform.system())
+print(platform.system_alias(platform.system(), platform.release(), platform.version()))
+print(platform.release())
+print(platform.platform())
 
 app = typer.Typer(help="backplane CLI")
 
@@ -103,7 +115,7 @@ def install():
 
         try:
             backplane_repo = os.getenv(
-                "BACKPLANE_REPOSITORY", "git@gitlab.com:p3r.one/backplane.git"
+                "BACKPLANE_REPOSITORY", "https://gitlab.com/p3r.one/backplane"
             )
             clone_command = (
                 f"git clone {backplane_repo} {backplane['default_context_dir']}"
@@ -338,7 +350,7 @@ def start(
         result = runCommand(docker_compose_command, project_dir)
         if result.returncode != 0:
             typer.secho(
-                f"Failed to start {service} in {backplane['active_context_dir']}: {result.output}",
+                f"Failed to start {service} in {backplane['active_context_dir']}: {result.stdout}",
                 err=True,
                 fg=typer.colors.RED,
             )
@@ -422,7 +434,7 @@ def stop(
         result = runCommand(docker_compose_command, project_dir)
         if result.returncode != 0:
             typer.secho(
-                f"Failed to stop {service} in {backplane['active_context_dir']}: {result.output}",
+                f"Failed to stop {service} in {backplane['active_context_dir']}: {result.stdout}",
                 err=True,
                 fg=typer.colors.RED,
             )
@@ -546,20 +558,25 @@ def logs(
                 print(container.logs(tail=200).decode())
 
 
-@app.command()
-def version():
-    """
-    Show apollo's version
-    """
+def version_callback(value: bool):
+    if value:
+        typer.echo(f"backplane CLI: {__version__}")
+        raise typer.Exit()
 
-    version = os.getenv("APOLLO_VERSION")
 
-    if not version:
-        typer.secho(f"No version found", err=True, fg=typer.colors.RED)
-        raise typer.Exit(code=1)
+def checkPrerequisites():
+    # Check for Docker
+    if not which("docker"):
+        typer.secho("Docker not installed", err=True, fg=typer.colors.RED)
+        sys.exit(1)
 
-    typer.secho(f"{version}", err=False, fg=typer.colors.GREEN)
-    return version
+    if not which("docker-compose"):
+        typer.secho("docker-compose not installed", err=True, fg=typer.colors.RED)
+        sys.exit(1)
+
+    if not which("git"):
+        typer.secho("git not installed", err=True, fg=typer.colors.RED)
+        sys.exit(1)
 
 
 @app.callback()
@@ -569,16 +586,10 @@ def callback(
     environment: str = typer.Option(
         "development", "--environment", "-e", help="Environment"
     ),
+    version: Optional[bool] = typer.Option(
+        None, "--version", callback=version_callback, is_eager=True
+    ),
 ):
-    # Check for Docker
-    if not which("docker"):
-        typer.secho(f"Docker not installed", err=True, fg=typer.colors.RED)
-        raise typer.Exit(code=1)
-
-    if not which("docker-compose"):
-        typer.secho(f"docker-compose not installed", err=True, fg=typer.colors.RED)
-        raise typer.Exit(code=1)
-
     backplane["verbosity"] = verbosity
     backplane["environment"] = os.getenv("backplane['environment']", "development")
     backplane["config_dir"] = os.getenv(
@@ -594,6 +605,8 @@ def callback(
     )
     backplane["active_context_dir"] = backplane["default_context_dir"]
 
+    checkPrerequisites()
+
 
 if __name__ == "__main__":
     app()
